@@ -9,6 +9,25 @@
 # import sys
 # sys.setrecursionlimit(n)
 
+from openapi_client.model.audiences_sub_object import AudiencesSubObject
+from openapi_client.model.campaign_clone_query import CampaignCloneQuery
+from openapi_client.model.campaign_clone_query_as_sub_resource import CampaignCloneQueryAsSubResource
+from openapi_client.model.campaign_clone_query_as_sub_resource_attributes import CampaignCloneQueryAsSubResourceAttributes
+from openapi_client.model.campaign_create_query import CampaignCreateQuery
+from openapi_client.model.campaign_create_query_as_sub_resource import CampaignCreateQueryAsSubResource
+from openapi_client.model.campaign_create_query_as_sub_resource_attributes import CampaignCreateQueryAsSubResourceAttributes
+from openapi_client.model.campaign_message_partial_update_query import CampaignMessagePartialUpdateQuery
+from openapi_client.model.campaign_message_partial_update_query_as_sub_resource import CampaignMessagePartialUpdateQueryAsSubResource
+from openapi_client.model.campaign_message_partial_update_query_as_sub_resource_attributes import CampaignMessagePartialUpdateQueryAsSubResourceAttributes
+from openapi_client.model.campaign_partial_update_query import CampaignPartialUpdateQuery
+from openapi_client.model.campaign_partial_update_query_as_sub_resource import CampaignPartialUpdateQueryAsSubResource
+from openapi_client.model.campaign_partial_update_query_as_sub_resource_attributes import CampaignPartialUpdateQueryAsSubResourceAttributes
+from openapi_client.model.campaign_send_job_create_query import CampaignSendJobCreateQuery
+from openapi_client.model.campaign_send_job_create_query_as_sub_resource import CampaignSendJobCreateQueryAsSubResource
+from openapi_client.model.campaign_send_job_create_query_as_sub_resource_attributes import CampaignSendJobCreateQueryAsSubResourceAttributes
+from openapi_client.model.campaign_send_job_partial_update_query import CampaignSendJobPartialUpdateQuery
+from openapi_client.model.campaign_send_job_partial_update_query_as_sub_resource import CampaignSendJobPartialUpdateQueryAsSubResource
+from openapi_client.model.campaign_send_job_partial_update_query_as_sub_resource_attributes import CampaignSendJobPartialUpdateQueryAsSubResourceAttributes
 from openapi_client.model.catalog_category_create_job_create_query import CatalogCategoryCreateJobCreateQuery
 from openapi_client.model.catalog_category_create_job_create_query_as_sub_resource import CatalogCategoryCreateJobCreateQueryAsSubResource
 from openapi_client.model.catalog_category_create_job_create_query_as_sub_resource_attributes import CatalogCategoryCreateJobCreateQueryAsSubResourceAttributes
@@ -66,6 +85,10 @@ from openapi_client.model.catalog_variant_update_job_create_query_as_sub_resourc
 from openapi_client.model.catalog_variant_update_query import CatalogVariantUpdateQuery
 from openapi_client.model.catalog_variant_update_query_as_sub_resource import CatalogVariantUpdateQueryAsSubResource
 from openapi_client.model.catalog_variant_update_query_as_sub_resource_attributes import CatalogVariantUpdateQueryAsSubResourceAttributes
+from openapi_client.model.content_sub_object import ContentSubObject
+from openapi_client.model.data_privacy_create_deletion_job_query import DataPrivacyCreateDeletionJobQuery
+from openapi_client.model.data_privacy_create_deletion_job_query_as_sub_resource import DataPrivacyCreateDeletionJobQueryAsSubResource
+from openapi_client.model.data_privacy_create_deletion_job_query_as_sub_resource_attributes import DataPrivacyCreateDeletionJobQueryAsSubResourceAttributes
 from openapi_client.model.email_message_content import EmailMessageContent
 from openapi_client.model.email_tracking_options import EmailTrackingOptions
 from openapi_client.model.error_source import ErrorSource
@@ -99,13 +122,13 @@ from openapi_client.model.included_profile import IncludedProfile
 from openapi_client.model.included_profiles import IncludedProfiles
 from openapi_client.model.included_profiles_attributes import IncludedProfilesAttributes
 from openapi_client.model.included_segments import IncludedSegments
+from openapi_client.model.included_tags import IncludedTags
 from openapi_client.model.included_variants import IncludedVariants
 from openapi_client.model.included_variants_attributes import IncludedVariantsAttributes
 from openapi_client.model.included_variants_links import IncludedVariantsLinks
 from openapi_client.model.list_create_query import ListCreateQuery
 from openapi_client.model.list_create_query_as_sub_resource import ListCreateQueryAsSubResource
 from openapi_client.model.list_create_query_as_sub_resource_attributes import ListCreateQueryAsSubResourceAttributes
-from openapi_client.model.list_delete_query_as_sub_resource import ListDeleteQueryAsSubResource
 from openapi_client.model.list_members_add_query import ListMembersAddQuery
 from openapi_client.model.list_members_add_query_data_inner import ListMembersAddQueryDataInner
 from openapi_client.model.list_members_delete_query import ListMembersDeleteQuery
@@ -136,6 +159,11 @@ from openapi_client.model.sms_tracking_options import SMSTrackingOptions
 from openapi_client.model.segment_partial_update_query import SegmentPartialUpdateQuery
 from openapi_client.model.segment_partial_update_query_as_sub_resource import SegmentPartialUpdateQueryAsSubResource
 from openapi_client.model.send_options import SendOptions
+from openapi_client.model.send_options_sub_object import SendOptionsSubObject
+from openapi_client.model.send_strategy_sub_object import SendStrategySubObject
+from openapi_client.model.send_strategy_sub_object_options import SendStrategySubObjectOptions
+from openapi_client.model.send_time_sub_object import SendTimeSubObject
+from openapi_client.model.static_schedule_options import StaticScheduleOptions
 from openapi_client.model.subscription import Subscription
 from openapi_client.model.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
 from openapi_client.model.subscription_create_job_create_query_as_sub_resource import SubscriptionCreateJobCreateQueryAsSubResource
@@ -144,16 +172,29 @@ from openapi_client.model.suppression import Suppression
 from openapi_client.model.suppression_create_job_create_query import SuppressionCreateJobCreateQuery
 from openapi_client.model.suppression_create_job_create_query_as_sub_resource import SuppressionCreateJobCreateQueryAsSubResource
 from openapi_client.model.suppression_create_job_create_query_as_sub_resource_attributes import SuppressionCreateJobCreateQueryAsSubResourceAttributes
+from openapi_client.model.tag_create_query import TagCreateQuery
+from openapi_client.model.tag_create_query_as_sub_resource import TagCreateQueryAsSubResource
+from openapi_client.model.tag_create_query_as_sub_resource_attributes import TagCreateQueryAsSubResourceAttributes
+from openapi_client.model.tag_group_create_query import TagGroupCreateQuery
+from openapi_client.model.tag_group_create_query_as_sub_resource import TagGroupCreateQueryAsSubResource
+from openapi_client.model.tag_group_create_query_as_sub_resource_attributes import TagGroupCreateQueryAsSubResourceAttributes
+from openapi_client.model.tag_group_update_query import TagGroupUpdateQuery
+from openapi_client.model.tag_group_update_query_as_sub_resource import TagGroupUpdateQueryAsSubResource
+from openapi_client.model.tag_group_update_query_as_sub_resource_attributes import TagGroupUpdateQueryAsSubResourceAttributes
+from openapi_client.model.tag_update_query import TagUpdateQuery
+from openapi_client.model.tag_update_query_as_sub_resource import TagUpdateQueryAsSubResource
 from openapi_client.model.template_clone_query import TemplateCloneQuery
 from openapi_client.model.template_clone_query_as_sub_resource import TemplateCloneQueryAsSubResource
 from openapi_client.model.template_clone_query_as_sub_resource_attributes import TemplateCloneQueryAsSubResourceAttributes
 from openapi_client.model.template_create_query import TemplateCreateQuery
 from openapi_client.model.template_create_query_as_sub_resource import TemplateCreateQueryAsSubResource
 from openapi_client.model.template_create_query_as_sub_resource_attributes import TemplateCreateQueryAsSubResourceAttributes
-from openapi_client.model.template_delete_query_as_sub_resource import TemplateDeleteQueryAsSubResource
 from openapi_client.model.template_update_query import TemplateUpdateQuery
 from openapi_client.model.template_update_query_as_sub_resource import TemplateUpdateQueryAsSubResource
 from openapi_client.model.template_update_query_as_sub_resource_attributes import TemplateUpdateQueryAsSubResourceAttributes
+from openapi_client.model.throttled_schedule_options import ThrottledScheduleOptions
+from openapi_client.model.tracking_options_sub_object import TrackingOptionsSubObject
+from openapi_client.model.utm_params_sub_object import UTMParamsSubObject
 from openapi_client.model.unsubscription_create_job_create_query import UnsubscriptionCreateJobCreateQuery
 from openapi_client.model.unsubscription_create_job_create_query_as_sub_resource import UnsubscriptionCreateJobCreateQueryAsSubResource
 from openapi_client.model.unsubscription_create_job_create_query_as_sub_resource_attributes import UnsubscriptionCreateJobCreateQueryAsSubResourceAttributes
